@@ -42,19 +42,21 @@
 #include <KWindowSystem>
 #include <KToolBarPopupAction>
 
-//#include <kdialog.h>   //ooo
-#include <kconfiggroup.h>   //ooo
+//#include <kdialog.h>		//ooo
+#include <kconfiggroup.h>	//ooo
 
-#include "babylon.h"
+//#include "babylon.h"
 #include "qtrans.h"
-#include "settings.h"   //ooo
-//#include "settings_widg.h"   //ooo
-//#include "html_widget.h"   //ooo   view()
+#include "settings.h"		//ooo
+//#include "settings_widg.h"	//ooo
+//#include "html_widget.h"	//ooo   view()
 #include "utils.h"
 
 //#define DEBUG_1
 //#define DEBUG_2
 //#define DEBUG_3
+//#define DEBUG_4
+//#define DEBUG_4a
 
 QTrans::QTrans(QWidget *parent, KAboutData *aboutData) : KMainWindow(parent)
 {
@@ -77,10 +79,21 @@ QTrans::QTrans(QWidget *parent, KAboutData *aboutData) : KMainWindow(parent)
 	//setMinimumSize(160, 160);
 	//resize(600, 230);
 
+	progressBar = new QProgressBar(this);	//ooo
+	progressBar->setRange(0, 100);		//ooo
+	progressBar->setMaximumSize(100, 16);	//ooo
+	//progressBar->setMaximumWidth(100);	//ooo
+	progressBar->hide();			//ooo
+
+	connect(Out, SIGNAL(loadProgress(int)), progressBar, SLOT(show()));		//ooo
+	connect(Out, SIGNAL(loadProgress(int)), progressBar, SLOT(setValue(int)));	//ooo
+	connect(Out, SIGNAL(loadFinished(bool)), progressBar, SLOT(hide()));		//ooo
+
 	createActions();
 	createMenus();
 	createTrayIcon();
 	setupActions();
+	createStatusBar();	//ooo
 
 	//kapp->setTopWidget( this );
 
@@ -117,6 +130,20 @@ QTrans::QTrans(QWidget *parent, KAboutData *aboutData) : KMainWindow(parent)
 	ToolBar = new KToolBar(this);
 	ToolBar->setToolButtonStyle(Qt::ToolButtonIconOnly);
 
+/*	progressBar = new QProgressBar(this);	//ooo
+	progressBar->setMaximumWidth(100);	//ooo
+
+	connect(Out,SIGNAL(loadProgress(int)),progressBar,SLOT(setValue(int)));	//ooo
+*/
+	//progressBar->setValue(50);	//ooo
+
+	//menubar = new QMenuBar(this);	//ooo
+
+	//helpMenu = new QMenu(this);	//ooo
+	//helpMenu = menuBar()->addMenu(tr("&Help"));	//ooo
+
+	//menubar->addMenu(helpMenu);	//ooo
+
 	//connect( aboutAct, SIGNAL(triggered()), HelpMenu, SLOT(aboutApplication())); //ooo
 	//connect( aboutAct, SIGNAL(triggered()), this, SLOT(slot_About()));
 
@@ -150,6 +177,8 @@ QTrans::QTrans(QWidget *parent, KAboutData *aboutData) : KMainWindow(parent)
 	ToolBar->addAction(exitAct);
 	ToolBar->addSeparator();
 	ToolBar->addWidget(combo);
+	ToolBar->addSeparator();		//ooo
+	//ToolBar->addWidget(progressBar);	//ooo
 
 /*	Out->setFont(fontType.family(), fontType.pointSize(), Charset);
 	Out->bgColor = bgColor;
@@ -157,7 +186,8 @@ QTrans::QTrans(QWidget *parent, KAboutData *aboutData) : KMainWindow(parent)
 	Out->expressionTxtColor = expressionTxtColor;	//ooo
 	Out->sentencePartTxtColor = sentencePartTxtColor;	//ooo
 */
-	Out->setFont(fontType.family(), fontType.pointSize(), Charset);
+	//Out->setFont(fontType.family(), fontType.pointSize(), Charset);
+	Out->setFont(fontType.family(), fontType.pointSize(), fontType.style(), fontType.weight(), Charset);	//ooo
 	Out->bgColor = bgColor;
 	Out->txtColor = txtColor;
 	Out->expressionTxtColor = expressionTxtColor;	//ooo
@@ -176,11 +206,22 @@ QTrans::QTrans(QWidget *parent, KAboutData *aboutData) : KMainWindow(parent)
 	//setCentralWidget(centralWidget);	//ooo
 	//Out->clear();
 	Out->clear();	//ooo
+
 	if (stayOnTop) {
 		stayOnTop = false;
 		slot_OnTop();
 	}
 
+	if (wordStartsWith) {			//ooo
+		wordStartsWith = false;
+		slot_WordStartsWith();
+	} else if (wholeWordsOnly) {		//ooo
+		wholeWordsOnly = false;
+		slot_WholeWordsOnly();
+	} else {
+		wordContains = true;		//ooo
+	}
+
 	//translate if a word is copied to clipboard
 	clip = kapp->clipboard();
 	connect(clip,SIGNAL(dataChanged()),this,SLOT(slot_ClipChanged()));
@@ -210,6 +251,7 @@ QTrans::QTrans(QWidget *parent, KAboutData *aboutData) : KMainWindow(parent)
             this, SLOT(iconActivated(QSystemTrayIcon::ActivationReason)));
 */
 	trayIcon->setIcon(KIcon("qtrans"));
+
 }
 
 
@@ -226,6 +268,22 @@ void QTrans::slot_Copy()
 }
 
 
+void QTrans::createStatusBar()			//ooo
+{
+	if (StatusBarSelected) {
+		QMainWindow::statusBar()->showMessage(tr("Ready"));
+		QMainWindow::statusBar()->insertPermanentWidget(0, progressBar, 0);
+	}
+
+/*	if (Dic != NULL) {
+		QMainWindow::statusBar()->showMessage(tr("Ready"));
+	} else {
+		QMainWindow::statusBar()->showMessage("Time elapsed: %d ms", Dic->t.elapsed());
+	}
+*/
+}
+
+
 void QTrans::mousePressEvent(QMouseEvent *event)	//ooo
 {
 /*	KMessageBox::sorry(this, i18n("mousePressEvent!"));
@@ -276,6 +334,9 @@ void QTrans::mousePressEvent(QMouseEvent *event)	//ooo
 			languageMenu->addAction(compactModeAct);
 		}
 		languageMenu->addAction(stayOnTopAct);
+		//languageMenu->addSeparator();
+		languageMenu->addAction(wordStartsWithAct);	//ooo
+		languageMenu->addAction(wholeWordsOnlyAct);	//ooo
 		languageMenu->addSeparator();
 		if (enabled) {
 			languageMenu->addAction(Dock->disableAct);
@@ -294,11 +355,22 @@ void QTrans::mousePressEvent(QMouseEvent *event)	//ooo
 /*-- Translate a QString and Update the View --*/
 void QTrans::Translate(QString EngWord, int ind)
 {
+
+	QString strStatusBar;		//ooo
+	QString strTimeElapsed;		//ooo
+	NumOfLines = 0;
+
 	//QMessageBox::about(this, tr("About Diagram Scene"), tr("Translate(: 1"));
 	//Out->clear();
-	Out->clear();	//ooo
 
-	Babylon *Dic = new Babylon();
+	if (StatusBarSelected) {			//ooo
+		QMainWindow::statusBar()->showMessage(tr("Ready"));
+	}
+
+	//Out->clear();	//ooo
+
+	//Babylon *Dic = new Babylon();
+	Dic = new Babylon();			//ooo
 
 	if (bab_dict->count()==0) {
 		KMessageBox::sorry(this,i18n("No dictionary is defined"));
@@ -311,11 +383,19 @@ void QTrans::Translate(QString EngWord, int ind)
 		KMessageBox::sorry(this, i18n("Could not open the dics!"));
 		return;
 	}
+
+	t.start();	//ooo
+
+	#ifdef DEBUG_4a
+		qDebug() << "wordStartsWith = " << wordStartsWith << ", wordContains = " << wordContains << ", wholeWordsOnly = " << wholeWordsOnly;
+	#endif
+
 	//QString text= Dic->translateAndFormat(EngWord);
 	//QString text = Dic->translateAndFormat(EngWord, Item.fileName);   //ooo
 	//QString text = Dic->translateAndFormat(EngWord, Item.fileName, Item.codecID);   //ooo
 	//QString text = Dic->translateAndFormat(EngWord, Item.fileName, Item.codecID, Item.directionID);   //ooo
-	QString text = Dic->translateAndFormat(EngWord, Item);   //ooo
+	//QString text = Dic->translateAndFormat(EngWord, Item, NumOfLines);   //ooo
+	QString text = Dic->translateAndFormat(EngWord, Item, NumOfLines, wordStartsWith, wordContains, wholeWordsOnly);   //ooo
 
 	if (text==QString::null)
 		return;
@@ -325,10 +405,33 @@ void QTrans::Translate(QString EngWord, int ind)
 		return;
 	delete Dic;
 
+	//QMainWindow::statusBar()->showMessage("Time elapsed: %d ms", t.elapsed());	//ooo
+
+/*	strStatusBar = "Time elapsed: ";			//ooo
+	strStatusBar += strTimeElapsed.setNum(t.elapsed());	//ooo
+	strStatusBar += " ms";					//ooo
+*/
+	//strStatusBar.sprintf("Time elapsed: %d ms	%s", t.elapsed(), "Dictionary Name");	//ooo
+
+	if (StatusBarSelected) {
+		//strStatusBar = QString("Time elapsed: %1 ms %2 %3").arg(t.elapsed()).arg("	").arg(Item.fileName.section("/", -1));		//ooo
+		//strStatusBar = QString("Time elapsed: %1 ms %2 %3 %4 %5 %6").arg(t.elapsed()).arg(" * ").arg(Item.fileName.section("/", -1)).arg(" * ").arg("Number of lines: ").arg(NumOfLines);		//ooo
+		strStatusBar = QString("Time elapsed: %1 ms %2 %3 %4 Number of lines: %6").arg(t.elapsed()).arg(" * ").arg(Item.fileName.section("/", -1)).arg(" * ").arg(NumOfLines);		//ooo
+		//strStatusBar = QString("Time elapsed: %1 ms * %2 * Number of lines: %3").arg(t.elapsed()).arg(Item.fileName.section("/", -1)).arg(NumOfLines);		//ooo
+		QMainWindow::statusBar()->showMessage(strStatusBar);	//ooo
+		//QMainWindow::statusBar()->addWidget(progressBar);	//ooo
+	}
+
+#ifdef DEBUG_4
+	qDebug() << "Item.fileName: " << Item.fileName;
+#endif
+
 	//QMessageBox::about(this, tr("About Diagram Scene"), tr("Translate(: 2"));
 	//Out->setOut(text);
 	Out->setOut(text);	//ooo
 
+	//QMainWindow::statusBar()->showMessage("Time elapsed: %d ms", t.elapsed());	//ooo
+
 	if ( isVisible() && (EngWord != combo->currentText()) ) {
 		combo->insertItem(0, EngWord);
 		//combo->setCurrentItem(0);   //KComboBox
@@ -448,6 +551,12 @@ void QTrans::createActions()
 	stayOnTopAct = new QAction( i18n("&Stay on Top"), this );
 	stayOnTopAct->setCheckable(true);
 
+	wordStartsWithAct = new QAction( i18n("&Word begins with ..."), this );			//ooo
+	wordStartsWithAct->setCheckable(true);
+
+	wholeWordsOnlyAct = new QAction( i18n("&Whole words only"), this );			//ooo
+	wholeWordsOnlyAct->setCheckable(true);
+
 	disableAct = new QAction( i18n("&Disable"), this );
 	enableAct = new QAction( i18n("&Enable"), this );
 
@@ -455,6 +564,9 @@ void QTrans::createActions()
 	connect( normalModeAct, SIGNAL(triggered()), SLOT(toggleMode()) );
 	connect( stayOnTopAct, SIGNAL(triggered()), SLOT(slot_OnTop()) );
 
+	connect( wordStartsWithAct, SIGNAL(triggered()), SLOT(slot_WordStartsWith()) );		//ooo
+	connect( wholeWordsOnlyAct, SIGNAL(triggered()), SLOT(slot_WholeWordsOnly()) );		//ooo
+
 	connect( disableAct, SIGNAL(triggered()), SLOT(slot_Enable()) );
 	connect( enableAct, SIGNAL(triggered()), SLOT(slot_Enable()) );
 
@@ -507,7 +619,14 @@ void QTrans::toggleMode()
 		w = Out->/*view()->*/width();
 		h = Out->/*view()->*/height();
 		ToolBar->hide();
-		resize(w, h + ToolBar->height());
+
+		if (StatusBarSelected) {			//ooo
+			QMainWindow::statusBar()->hide();
+			resize(w, h + ToolBar->height()+QMainWindow::statusBar()->height());
+		} else {
+			resize(w, h + ToolBar->height());
+		}
+
 		compactMode = true;
 		compactModeAct->setVisible(false);
 		normalModeAct->setVisible(true);
@@ -518,6 +637,12 @@ void QTrans::toggleMode()
 		hide();
 		show();
 		ToolBar->show();
+
+		if (StatusBarSelected) {			//ooo
+			QMainWindow::statusBar()->show();
+			QMainWindow::statusBar()->showMessage(tr("Ready"));
+		}
+
 		resize(w,h);
 		compactMode = false;
 		compactModeAct->setVisible(true);
@@ -540,6 +665,42 @@ void QTrans::slot_OnTop()
 }
 
 
+void QTrans::slot_WordStartsWith()	//ooo
+{
+	if (!wordStartsWith) {
+		wordStartsWith = true;
+		wordContains = false;
+		wholeWordsOnly = false;
+		wordStartsWithAct->setChecked(true);
+		wholeWordsOnlyAct->setChecked(false);
+	} else {
+		wordStartsWith = false;
+		wordContains = true;
+		wholeWordsOnly = false;
+		wordStartsWithAct->setChecked(false);
+		wholeWordsOnlyAct->setChecked(false);
+	}
+}
+
+
+void QTrans::slot_WholeWordsOnly()	//ooo
+{
+	if (!wholeWordsOnly) {
+		wordStartsWith = false;
+		wordContains = false;
+		wholeWordsOnly = true;
+		wordStartsWithAct->setChecked(false);
+		wholeWordsOnlyAct->setChecked(true);
+	} else {
+		wordStartsWith = false;
+		wordContains = true;
+		wholeWordsOnly = false;
+		wordStartsWithAct->setChecked(false);
+		wholeWordsOnlyAct->setChecked(false);
+	}
+}
+
+
 void QTrans::slot_Combo(const QString &Str)
 {
 	Translate(Str);
@@ -640,6 +801,12 @@ void QTrans::closeEvent(QCloseEvent *event)
 		if ( cg.readEntry("stayOnTop",false) != stayOnTop ) {
 			cg.writeEntry("stayOnTop",stayOnTop);
 		}
+		if ( cg.readEntry("wordStartsWith",false) != wordStartsWith ) {		//ooo
+			cg.writeEntry("wordStartsWith",wordStartsWith);
+		}
+		if ( cg.readEntry("wholeWordsOnly",false) != wholeWordsOnly ) {		//ooo
+			cg.writeEntry("wholeWordsOnly",wholeWordsOnly);
+		}
 		cg.sync();
 
 		//if (event->KeyPress)
@@ -734,6 +901,8 @@ void QTrans::slot_Exit(bool ask)
 	cg.writeEntry("compactMode",compactMode);
 	//settings.setValue("enabled",enabled);
 	cg.writeEntry("stayOnTop",stayOnTop);
+	cg.writeEntry("wordStartsWith",wordStartsWith);		//ooo
+	cg.writeEntry("wholeWordsOnly",wholeWordsOnly);		//ooo
 
 	cg.sync();
 
