@@ -39,15 +39,22 @@
 #include <QTimer>
 #include <QSystemTrayIcon>
 #include <KHelpMenu>
-#include <QMouseEvent>	//ooo
-#include <QTextEdit>	//ooo
-#include <QWebView>	//ooo
+#include <QMouseEvent>		//ooo
+#include <QTextEdit>		//ooo
+#include <QWebView>		//ooo
 //#include <QtWebKit/QWebView>	//ooo
-#include <QKeyEvent>	//ooo
+#include <QKeyEvent>		//ooo
+
+#include <QMenu>		//ooo
+#include <QMenuBar>		//ooo
+#include <QStatusBar>		//ooo
+#include <QTime>		//ooo
+#include <QProgressBar>		//ooo
 
 #include "systemtray.h"
 #include "settings_widg.h"
 #include "html_widget.h"
+#include "babylon.h"		//ooo
 
 //#include "previewer.h"	//ooo
 
@@ -69,6 +76,7 @@ public:
 	~QTrans();
 
 	Html_Widget *Out;
+	Babylon *Dic;			//ooo
 	//Previewer *centralWidget;	//ooo
 
 public slots:
@@ -85,6 +93,8 @@ public slots:
 	void slot_ShortCut();
 	void toggleMode();
 	void slot_OnTop();
+	void slot_WordStartsWith();		//ooo
+	void slot_WholeWordsOnly();		//ooo
 	void slot_Combo(const QString &);
 
 	void chooseLibrary(QAction *action);
@@ -114,6 +124,8 @@ public:
 
 	QTimer *Time;
 	QString English_Path;
+	QTime t;		//ooo
+	int NumOfLines;		//ooo
 
 	QList<Dictionary> *bab_dict;
 	QWebView *view;
@@ -126,11 +138,16 @@ public:
 		DontClose,
 		DockIcon,
 		StartMin,
-		MouseSelected,	//ooo
+		MouseSelected,		//ooo
+		StatusBarSelected,	//ooo
 		enableShortCut,
 		compactMode,
 		hideTask,
-		stayOnTop;
+		stayOnTop,
+		wordStartsWith,		//ooo
+		wordContains,		//ooo
+		wordEndsWith,		//ooo
+		wholeWordsOnly;		//ooo
 	/*-- --*/
 
 	QFont fontType;
@@ -142,6 +159,7 @@ public:
 	QString sentencePartTxtColor;	//ooo
 	//KComboBox *combo;
 	QComboBox *combo;
+	QProgressBar *progressBar;	//ooo
 	QMenu *languageMenu;
 
 	QList<QAction*> actionsList;
@@ -152,6 +170,7 @@ private:
 	void createActions();
 	void createMenus();
 	void setupActions();
+	void createStatusBar();		//ooo
 
 	void createTrayIcon();
 	QAction *exitAct;
@@ -163,6 +182,8 @@ private:
 	QAction *normalModeAct;
 	QAction *compactModeAct;
 	QAction *stayOnTopAct;
+	QAction *wordStartsWithAct;	//ooo
+	QAction *wholeWordsOnlyAct;	//ooo
 	QAction *disableAct;
 	QAction *enableAct;
 
@@ -176,6 +197,9 @@ private:
 	//QMenu *trayIconMenu;   //no addTitle possible
 	KMenu *trayIconMenu;
 
+	QMenu *helpMenu;	//ooo
+	QMenuBar *menubar;	//ooo
+
 protected:
 	void closeEvent(QCloseEvent *event);
 	//void closeEvent(QEvent *event);
